@@ -1,6 +1,5 @@
 package CIF::Client::Plugin::Html;
 use base 'CIF::Client::Plugin::Output';
-use CIF::Client::Support qw(confor);
 
 use HTML::Table;
 
@@ -14,16 +13,6 @@ sub write_out {
     my $query = $feed->{'query'};
     my $hash = $feed->{'feed'};
     my $group_map = ($config->{'group_map'}) ? $hash->{'group_map'} : undef;
-    
-    my @config_search_path = ('claoverride',  $feed->{'query'}, 'client' );
-
-    # fields class evenrowclass oddrowclass display
-    
-    my $cfg_fields = confor($config, \@config_search_path, 'fields', undef);
-    my $cfg_display = confor($config, \@config_search_path, 'display', undef);
-    my $cfg_class = confor($config, \@config_search_path, 'class', undef);
-    my $cfg_evenrowclass = confor($config, \@config_search_path, 'evenrowclass', undef);
-    my $cfg_oddrowclass = confor($config, \@config_search_path, 'oddrowclass', undef);
 
     my $created = $hash->{'created'} || $hash->{'detecttime'};
     my $feedid = $hash->{'id'};
@@ -48,9 +37,6 @@ sub write_out {
         if(exists($t->{'address'})){
             push(@cols,('address'));
         }
-        if(exists($t->{'rdata'})){
-            push(@cols,'rdata');
-        }
         if(exists($t->{'protocol'})){
             push(@cols,'protocol');
         }
@@ -82,20 +68,19 @@ sub write_out {
             'alternativeid_restriction',
             'alternativeid',
         ));
+   }
+   if($config->{'fields'}){
+        @cols = @{$config->{'fields'}};
     }
-    if($cfg_fields) {
-        @cols = split(',', $cfg_fields);
-    }
-    
-    if($cfg_display) {
-        @cols = split(',', $cfg_display);
+    if(my $c = $self->{'config'}->{'display'}){
+        @cols = @$c;
     }
 
     my $table = HTML::Table->new(
         -head           => \@cols,
-        -class          => $cfg_class || '',
-        -evenrowclass   => $cfg_evenrowclass || '',
-        -oddrowclass    => $cfg_oddrowclass || '',
+        -class          => $config->{'class'} || '',
+        -evenrowclass   => $config->{'evenrowclass'} || '',
+        -oddrowclass    => $config->{'oddrowclass'} || '',
     );
 
     if(my $max = $self->{'max_desc'}){
