@@ -93,9 +93,6 @@ sub write_out {
             $r->{'address'} = substr($r->{'address'},0,31);
             $r->{'address'} .= '...';
         }
-        # strip out non-ascii (typically unicode) chars
-        # there are better ways to do this, but this works for now
-        $r->{'description'} =~ tr/\000-\177//cd;
         $table->load([ map { $r->{$_} } @cols]);
     }
     if($created){
@@ -118,10 +115,6 @@ sub write_out {
         $table = 'Feed Group ID: '.$feed_guid."\n".$table;
     }
     $table = "Query: ".$query."\n".$table;
-    unless($config->{'config'}->{'table_nowarning'}){
-        $table = 'WARNING: Turn off this warning by adding: \'table_nowarning = 1\' to your ~/.cif config'."\n\n".$table;
-        $table = 'WARNING: This table output not to be used for parsing, see "-p plugins" (via cif -h)'."\n".$table;
-    }
     return "\n".$table;
 }
 
